@@ -280,8 +280,12 @@ class Device(object):
 
     @property
     def attribution(self):
-        if self.__address and "licence" in self.__address:
-            return self.__address["licence"]
+        if (
+            self.__address
+            and "raw" in self.__address
+            and "licence" in self.__address["raw"]
+        ):
+            return self.__address["raw"]["licence"]
         return None
 
     @property
@@ -452,3 +456,57 @@ class Device(object):
         if not self.__iconId:
             return None
         return self.__iconId
+
+
+sample = {
+    "accuracy": 0.001,
+    "address": "Belcastro, Belcastro Lane, Eight Mile Plains, Brisbane, Queensland, 4113, Australia",
+    "bbox": {
+        "northeast": [-27.5854166, 153.0867724],
+        "southwest": [-27.5857226, 153.0865314],
+    },
+    "city": "Brisbane",
+    "confidence": 10,
+    "country": "Australia",
+    "country_code": "au",
+    "importance": 0.001,
+    "lat": -27.585563649999997,
+    "lng": 153.08665216347964,
+    "ok": True,
+    "osm_id": 621636139,
+    "osm_type": "way",
+    "place_id": 210004813,
+    "place_rank": 30,
+    "postal": "4113",
+    "quality": "house",
+    "raw": {
+        "place_id": 210004813,
+        "licence": "Data © OpenStreetMap contributors, ODbL 1.0. https://osm.org/copyright",
+        "osm_type": "way",
+        "osm_id": 621636139,
+        "boundingbox": ["-27.5857226", "-27.5854166", "153.0865314", "153.0867724"],
+        "lat": "-27.585563649999997",
+        "lon": "153.08665216347964",
+        "display_name": "Belcastro, Belcastro Lane, Eight Mile Plains, Brisbane, Queensland, 4113, Australia",
+        "place_rank": 30,
+        "category": "building",
+        "type": "house",
+        "importance": 0.001,
+        "address": {
+            "building": "Belcastro",
+            "road": "Belcastro Lane",
+            "suburb": "Eight Mile Plains",
+            "city": "Brisbane",
+            "state": "Queensland",
+            "postcode": "4113",
+            "country": "Australia",
+            "country_code": "au",
+        },
+    },
+    "region": "Queensland",
+    "state": "Queensland",
+    "status": "OK",
+    "street": "Belcastro Lane",
+    "suburb": "Eight Mile Plains",
+    "type": "house",
+}
